@@ -8,7 +8,11 @@ from typing import List, Optional, Tuple, Union
 import pandas as pd
 from openstef_dbc.data_interface import _DataInterface
 from openstef_dbc.services.weather import Weather
-from openstef_dbc.utils import genereate_datetime_index, process_datetime_range
+from openstef_dbc.utils import (
+    genereate_datetime_index,
+    process_datetime_range,
+    parse_influx_result,
+)
 
 
 class PredictorGroups(Enum):
@@ -103,33 +107,32 @@ class Predictor:
         datetime_end: datetime.datetime,
         forecast_resolution: str = None,
     ) -> pd.DataFrame:
-        database = "forecast_latest"
-        measurement = "marketprices"
         bind_params = {
-            "dstart": datetime_start.isoformat(),
-            "dend": datetime_end.isoformat(),
+            "_start": datetime_start,
+            "_stop": datetime_end,
         }
-        query = f"""
-            SELECT
-                "Price" FROM "{database}".."{measurement}"
-            WHERE
-                "Name" = 'APX' AND
-                time >= $dstart AND
-                time <= $dend
-        """
-        electricity_price = _DataInterface.get_instance().exec_influx_query(
-            query, bind_params
-        )
 
-        if not electricity_price:
+        query = f"""
+            from(bucket: "forecast_latest/autogen")
+                |> range(start: {bind_params["_start"].strftime('%Y-%m-%dT%H:%M:%SZ')}, stop: {bind_params["_stop"].strftime('%Y-%m-%dT%H:%M:%SZ')}) 
+                |> filter(fn: (r) => r._measurement == "marketprices" and r._field == "Price" and r.Name=="APX")
+        """
+
+        result = _DataInterface.get_instance().exec_influx_query(query, bind_params)
+
+        # For multiple Fields a list is returned.
+        if isinstance(result, list):
+            result = pd.concat(result)[["_value", "_field", "_time"]]
+
+        # Check if response is empty
+        if not result.empty:
+            electricity_price = parse_influx_result(result)
+        else:
             return pd.DataFrame(
                 index=genereate_datetime_index(
                     start=datetime_start, end=datetime_end, freq=forecast_resolution
                 )
             )
-
-        electricity_price = electricity_price["marketprices"]
-
         electricity_price.rename(columns=dict(Price="APX"), inplace=True)
 
         if forecast_resolution and electricity_price.empty is False:
@@ -160,40 +163,66 @@ class Predictor:
         # select all fields which start with 'sjv'
         # (there is also a 'year_created' tag in this measurement)
         bind_params = {
-            "dstart": datetime_start.isoformat(),
-            "dend": datetime_end.isoformat(),
+            "_start": datetime_start,
+            "_stop": datetime_end,
         }
 
+        sjv_profles = [
+            "E1A_AMI_A",
+            "E1A_AMI_I",
+            "E1A_AZI_A",
+            "E1A_AZI_I",
+            "E1B_AMI_A",
+            "E1B_AMI_I",
+            "E1B_AZI_A",
+            "E1B_AZI_I",
+            "E1C_AMI_A",
+            "E1C_AMI_I",
+            "E1C_AZI_A",
+            "E1C_AZI_I",
+            "E2A_AMI_A",
+            "E2A_AMI_I",
+            "E2A_AZI_A",
+            "E2A_AZI_I",
+            "E2B_AMI_A",
+            "E2B_AMI_I",
+            "E2B_AZI_A",
+            "E2B_AZI_I",
+            "E3A_A",
+            "E3A_I",
+            "E3B_A",
+            "E3B_I",
+            "E3C_A",
+            "E3C_I",
+            "E3D_A",
+            "E3D_I",
+            "E4A_A",
+            "E4A_I",
+        ]
+
+        field_selection = '" or r._field == "'.join(sjv_profles)
+
         query = f"""
-            SELECT
-                "E1A_AMI_A", "E1A_AMI_I", "E1A_AZI_A", "E1A_AZI_I",
-                "E1B_AMI_A", "E1B_AMI_I", "E1B_AZI_A", "E1B_AZI_I",
-                "E1C_AMI_A", "E1C_AMI_I", "E1C_AZI_A", "E1C_AZI_I",
-                "E2A_AMI_A", "E2A_AMI_I", "E2A_AZI_A", "E2A_AZI_I",
-                "E2B_AMI_A", "E2B_AMI_I", "E2B_AZI_A", "E2B_AZI_I",
-                "E3A_A", "E3A_I", 
-                "E3B_A", "E3B_I",
-                "E3C_A", "E3C_I",
-                "E3D_A", "E3D_I",
-                "E4A_A", "E4A_I" 
-            FROM "realised".."sjv"
-            WHERE
-                time >= $dstart AND
-                time <= $dend
+            from(bucket: "realised/autogen")
+                |> range(start: {bind_params["_start"].strftime('%Y-%m-%dT%H:%M:%SZ')}, stop: {bind_params["_stop"].strftime('%Y-%m-%dT%H:%M:%SZ')}) 
+                |> filter(fn: (r) => r._measurement == "sjv" and r._field == "{field_selection}")
         """
-        load_profiles = _DataInterface.get_instance().exec_influx_query(
+        result = _DataInterface.get_instance().exec_influx_query(
             query, bind_params=bind_params
         )
+        # For multiple Fields a list is returned.
+        if isinstance(result, list):
+            result = pd.concat(result)[["_value", "_field", "_time"]]
 
-        if not load_profiles:
+        if not result.empty:
+            load_profiles = parse_influx_result(result)
+        else:
             return pd.DataFrame(
                 index=genereate_datetime_index(
                     start=datetime_start, end=datetime_end, freq=forecast_resolution
                 )
             )
 
-        load_profiles = load_profiles["sjv"]
-
         if forecast_resolution and load_profiles.empty is False:
             load_profiles = load_profiles.resample(forecast_resolution).interpolate(
                 limit=3
